# This file was auto-generated by Fern from our API Definition.

import typing
from .custom_proxy import CustomProxy
from .session_config_v1proxy_item import SessionConfigV1ProxyItem

SessionConfigV1Proxy = typing.Union[bool, CustomProxy, typing.List[SessionConfigV1ProxyItem]]
